#!/usr/bin/env python2

# This Python script is the interface between the Comvette Cataloger application
# and the TinyTag library. Extracting metadata from media files is a mysterious
# and obscure art that is best left to experts.
#
# 1) The Comvette Cataloger passes a fully qualified media file name to this
#    Python script.
#
# 2) This script passes the media file name to the TinyTag library and the
#    tinytag library then returns a collection of metadata tags for the
#    specified media file.
#
# 3) This script then repackages the metadata tags in a JSON object and returns
#    the JSON object to the Comvette Cataloger application for processing.
#
# 4) This is repeated until the Comvette Cataloger has aquired all the metadata
#    it needs to build its database of available media files.
#
# TinyTag: https://pypi.org/project/tinytag/
#    tinytag is a library for reading music meta data of MP3, OGG, OPUS, MP4,
#    M4A, FLAC, WMA and Wave files with python.

from tinytag import TinyTag
import sys
import base64
import json

# Get the specified media file from the command line.
#
media_file = sys.argv[1]

# Get the metadata for the specified media file.
#
tag = TinyTag.get(media_file, image=True)

# If artwork is found, Base64 encode it so that its binary data
# can be included in the JSON object we're building.
#
AlbumArt = tag.get_image()
if AlbumArt is not None:
  AlbumArt = base64.encodestring(AlbumArt)

# The rest of the metadata is passed on as-is without any
# further processing.
#
AlbumName   = tag.album
AlbumArtist = tag.albumartist
AlbumYear   = tag.year
AlbumGenre  = tag.genre
DiscNumber  = tag.disc
TrackNumber = tag.track
TrackName   = tag.title
TrackArtist = tag.artist
Comment     = tag.comment

# Build a dictionary from the metadata tags.
#
data = {
  "AlbumArt"      : AlbumArt,
  "AlbumName"     : AlbumName,
  "AlbumArtist"   : AlbumArtist,
  "AlbumYear"     : AlbumYear,
  "AlbumGenre"    : AlbumGenre,
  "DiscNumber"    : DiscNumber,
  "TrackNumber"   : TrackNumber,
  "TrackName"     : TrackName,
  "TrackArtist"   : TrackArtist,
  "Comment"       : Comment
}

# Create a JSON object from the dictionary and write it to stdout.
#
sys.stdout.write(json.dumps(data, indent=2, sort_keys=True))
